/*
 * =======================================================================================
 *
 *      Filename:  perfmon_cascadelake.h
 *
 *      Description:  Header File of perfmon module for Intel CascadeLake.
 *
 *      Version:   4.3.3
 *      Released:  09.11.2018
 *
 *      Author:   Jan Treibig (jt), jan.treibig@gmail.com
 *                Thomas Gruber (tr), thomas.roehl@googlemail.com
 *      Project:  likwid
 *
 *      Copyright (C) 2018 RRZE, University Erlangen-Nuremberg
 *
 *      This program is free software: you can redistribute it and/or modify it under
 *      the terms of the GNU General Public License as published by the Free Software
 *      Foundation, either version 3 of the License, or (at your option) any later
 *      version.
 *
 *      This program is distributed in the hope that it will be useful, but WITHOUT ANY
 *      WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 *      PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 *
 *      You should have received a copy of the GNU General Public License along with
 *      this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * =======================================================================================
 */
#ifndef PERFMON_CASCADELAKE_H
#define PERFMON_CASCADELAKE_H

#include <perfmon_cascadelakeX_events.h>

static int perfmon_numArchEventsCascadelakeX = NUM_ARCH_EVENTS_CASCADELAKEX;

#endif //PERFMON_CASCADELAKE_H
